@@ -16,6 +16,7 @@ from GLXShell.plugins.builtins.dir import GLXDir
 from GLXShell.plugins.builtins.mkdir import GLXMkdir
 from GLXShell.plugins.builtins.pwd import GLXPwd
 from GLXShell.plugins.builtins.rmdir import GLXRmDir
+from GLXShell.plugins.builtins.sleep import GLXSleep
 from GLXShell.plugins.builtins.uname import GLXUname
 from GLXShell.plugins.builtins.which import GLXWhich
 
@@ -31,6 +32,7 @@ class GLXShPluginBuiltins(GLXShellCommands):
             {"name": "mkdir", "object": GLXMkdir()},
             {"name": "pwd", "object": GLXPwd()},
             {"name": "rmdir", "object": GLXRmDir()},
+            {"name": "sleep", "object": GLXSleep()},
             {"name": "uname", "object": GLXUname()},
             {"name": "which", "object": GLXWhich()},
         ]
