@@ -2,9 +2,9 @@ import os
 import cmd2
 import argparse
 
-from GLXShell.plugins.builtins import __version__
-from GLXShell.plugins.builtins import __appname__
-from GLXShell.plugins.builtins import __licence__
+from GLXShell.plugins.builtins import PLUGIN_VERSION
+from GLXShell.plugins.builtins import PLUGIN_DESCRIPTION
+from GLXShell.plugins.builtins import PLUGIN_WARRANTY
 
 which_parser = cmd2.Cmd2ArgumentParser(
     description="which  returns  the pathnames of the files (or links) which would be executed in the current "
@@ -40,9 +40,9 @@ class GLXWhich(cmd2.CommandSet):
     def which_print_version():
         cmd2.Cmd().poutput(
             "which ({name}) v{version}\n{licence}".format(
-                name=__appname__,
-                version=__version__,
-                licence=__licence__,
+                name=PLUGIN_DESCRIPTION,
+                version=PLUGIN_VERSION,
+                licence=PLUGIN_WARRANTY,
             )
         )
 
